@@ -7,6 +7,7 @@ import sys
 from typing import List, Optional
 
 from yd_commands.__init__ import __version__
+from yd_commands.settings import MAX_PARALLEL_TASK_BATCH_UPLOAD_THREADS
 from yd_commands.version import DOCS_URL
 
 
@@ -229,7 +230,8 @@ class CLIParser:
                 metavar="<interval_between_batches_in_seconds>",
                 help=(
                     "pause for user input between task batch submissions; if no"
-                    " pause interval is provided, user input is required to advance"
+                    " pause interval is provided, user input is required to advance; "
+                    "only valid when 'parallel-batches=1'"
                 ),
             )
             parser.add_argument(
@@ -258,6 +260,19 @@ class CLIParser:
                 required=False,
                 help="set the work requirement status to 'HELD' on submission",
             )
+            parser.add_argument(
+                "--parallel-batches",
+                "-l",
+                type=int,
+                required=False,
+                default=MAX_PARALLEL_TASK_BATCH_UPLOAD_THREADS,
+                help=(
+                    "the maximum number of parallel task batch "
+                    f"uploads (default={MAX_PARALLEL_TASK_BATCH_UPLOAD_THREADS})"
+                    "; set this to '1' for sequential batch upload"
+                ),
+                metavar="<max_number_of_parallel_batches>",
+            )
 
         if any(module in sys.argv[0] for module in ["provision", "instantiate"]):
             parser.add_argument(
@@ -354,6 +369,13 @@ class CLIParser:
                 required=False,
                 help="list all objects, at all levels in the prefix hierarchy",
             )
+            parser.add_argument(
+                "--non-exact-namespace-match",
+                "-N",
+                action="store_true",
+                required=False,
+                help="match all namespaces that contain the value of 'namespace'",
+            )
 
         if "download" in sys.argv[0]:
             parser.add_argument(
@@ -516,6 +538,18 @@ class CLIParser:
                 required=False,
                 help="list compute instances",
             )
+            parser.add_argument(
+                "--nodes",
+                action="store_true",
+                required=False,
+                help="list worker pool nodes",
+            )
+            parser.add_argument(
+                "--workers",
+                action="store_true",
+                required=False,
+                help="list all workers in a worker pool",
+            )
             parser.add_argument(
                 "--public-ips-only",
                 action="store_true",
@@ -674,12 +708,12 @@ class CLIParser:
 
         if "shutdown" in sys.argv[0]:
             parser.add_argument(
-                "worker_pool_list",
+                "worker_pool_nodes_list",
                 nargs="*",
                 default="",
-                metavar="<worker-pool-name-or-ID>",
+                metavar="<worker-pool-name-or-ID/node-id>",
                 type=str,
-                help="the name(s) or YellowDog ID(s) of the worker pool(s)",
+                help="the name(s) or YellowDog ID(s) of the worker pool(s) and/or ID(s) of nodes",
             )
             parser.add_argument(
                 "--follow",
@@ -1148,6 +1182,11 @@ class CLIParser:
     def all(self) -> Optional[bool]:
         return self.args.all
 
+    @property
+    @allow_missing_attribute
+    def non_exact_namespace_match(self) -> Optional[bool]:
+        return self.args.non_exact_namespace_match
+
     @property
     @allow_missing_attribute
     def details(self) -> Optional[bool]:
@@ -1253,6 +1292,11 @@ class CLIParser:
     def pause_between_batches(self) -> Optional[int]:
         return self.args.pause_between_batches
 
+    @property
+    @allow_missing_attribute
+    def parallel_batches(self) -> Optional[int]:
+        return self.args.parallel_batches
+
     @property
     @allow_missing_attribute
     def worker_pool_name(self) -> Optional[str]:
@@ -1260,8 +1304,8 @@ class CLIParser:
 
     @property
     @allow_missing_attribute
-    def worker_pool_list(self) -> Optional[List[str]]:
-        return self.args.worker_pool_list
+    def worker_pool_nodes_list(self) -> Optional[List[str]]:
+        return self.args.worker_pool_nodes_list
 
     @property
     @allow_missing_attribute
@@ -1328,6 +1372,16 @@ class CLIParser:
     def instances(self) -> Optional[bool]:
         return self.args.instances
 
+    @property
+    @allow_missing_attribute
+    def nodes(self) -> Optional[bool]:
+        return self.args.nodes
+
+    @property
+    @allow_missing_attribute
+    def workers(self) -> Optional[bool]:
+        return self.args.workers
+
     @property
     @allow_missing_attribute
     def allowances(self) -> Optional[bool]:
@@ -1491,7 +1545,7 @@ def lookup_module_description(module_name: str) -> Optional[str]:
     elif "delete" in module_name:
         suffix = "deleting objects in the Object Store"
     elif "shutdown" in module_name:
-        suffix = "shutting down Worker Pools"
+        suffix = "shutting down Worker Pools and Nodes"
     elif "terminate" in module_name:
         suffix = "terminating Compute Requirements"
     elif "list" in module_name:
