@@ -30,8 +30,6 @@ from yellowdog_client.model import (
     RequirementsAllowance,
     SourceAllowance,
     SourcesAllowance,
-    WorkerPoolStatus,
-    WorkerPoolSummary,
 )
 from yellowdog_client.model.exceptions import InvalidRequestException
 
@@ -42,11 +40,12 @@ from yd_commands.object_utilities import (
     clear_image_family_search_cache,
     find_compute_requirement_template_id_by_name,
     find_compute_source_template_id_by_name,
-    find_image_family_ids_by_name,
+    find_image_family_id_by_name,
     remove_allowances_matching_description,
 )
 from yd_commands.printing import print_error, print_json, print_log, print_warning
 from yd_commands.settings import (
+    NAMESPACE_PREFIX_SEPARATOR,
     RN_ALLOWANCE,
     RN_CONFIGURED_POOL,
     RN_CREDENTIAL,
@@ -143,28 +142,29 @@ def create_compute_source_template(resource: Dict):
     Handles all Source types.
     """
     try:
+        namespace = resource.get("namespace")
         source = resource.pop("source")  # Extract the Source properties
         source_type = source.pop("type").split(".")[-1]  # Extract Source type
         name = source["name"]
     except KeyError as e:
         raise Exception(f"Expected property to be defined ({e})")
 
-    # Allow image families to be referenced by name rather than ID
+    # Allow image families (etc.) to be referenced by name rather than ID
     global CLEAR_IMAGE_FAMILY_CACHE
     if CLEAR_IMAGE_FAMILY_CACHE:  # Update the IF cache if required
         clear_image_family_search_cache()
         CLEAR_IMAGE_FAMILY_CACHE = False
+
     image_id = source.get("imageId")
-    if image_id is not None:
-        if "ydid:imgfam:" not in image_id:
-            image_family_ids = find_image_family_ids_by_name(
-                client=CLIENT, image_family_name=image_id
-            )
-            if len(image_family_ids) > 0:
-                source["imageId"] = image_family_ids[0]
-                print_log(
-                    f"Replaced imageId name '{image_id}' with ID {image_family_ids[0]}"
-                )
+    if image_id is not None and not any(
+        [x in image_id for x in ["ydid:image:", "ydid:imggrp:", "ydid:imgfam:"]]
+    ):
+        image_family_id = find_image_family_id_by_name(
+            client=CLIENT, image_family_name=image_id
+        )
+        if image_family_id is not None:
+            source["imageId"] = image_family_id
+            print_log(f"Replaced imageId name '{image_id}' with ID {image_family_id}")
 
     if ARGS_PARSER.dry_run:
         resource["source"] = source
@@ -180,16 +180,17 @@ def create_compute_source_template(resource: Dict):
         "ComputeSourceTemplate", resource, source=compute_source
     )
 
+    # Prepend the namespace when searching for existing templates
+    if namespace is not None:
+        name = f"{namespace}{NAMESPACE_PREFIX_SEPARATOR}{name}"
+
     # Check for an existing ID
     source_id = find_compute_source_template_id_by_name(CLIENT, name)
     if source_id is None:
         compute_source = CLIENT.compute_client.add_compute_source_template(
             compute_source_template
         )
-        print_log(
-            f"Created Compute Source Template '{compute_source.source.name}'"
-            f" ({compute_source.id})"
-        )
+        print_log(f"Created Compute Source Template '{name}'" f" ({compute_source.id})")
     else:
         if not confirmed(f"Update existing Compute Source Template '{name}'?"):
             return
@@ -198,7 +199,7 @@ def create_compute_source_template(resource: Dict):
             compute_source_template
         )
         print_log(
-            f"Updated existing Compute Source Template '{compute_source.source.name}'"
+            f"Updated existing Compute Source Template '{name}'"
             f" ({compute_source.id})"
         )
 
@@ -217,6 +218,7 @@ def create_compute_requirement_template(resource: Dict):
     try:
         type = resource.pop("type").split(".")[-1]  # Extract type
         name = resource["name"]
+        namespace = resource.get("namespace")
     except KeyError as e:
         raise Exception(f"Expected property to be defined ({e})")
 
@@ -227,8 +229,41 @@ def create_compute_requirement_template(resource: Dict):
         clear_compute_source_template_cache()
         CLEAR_CST_CACHE = False
 
+    # Allow image families to be referenced by name rather than ID
+    global CLEAR_IMAGE_FAMILY_CACHE
+    if CLEAR_IMAGE_FAMILY_CACHE:  # Update the IF cache if required
+        clear_compute_source_template_cache()
+        CLEAR_IMAGE_FAMILY_CACHE = False
+
+    def _get_images_id(
+        image_str: str, context: Dict, key: str, report: bool = False
+    ) -> int:
+        """
+        Helper function to match an image family name into an ID.
+        """
+        if not any(
+            [x in image_str for x in ["ydid:image:", "ydid:imggrp:", "ydid:imgfam:"]]
+        ):
+            image_family_id = find_image_family_id_by_name(
+                client=CLIENT, image_family_name=image_str
+            )
+            if image_family_id is not None:
+                context[key] = image_family_id
+                if report:
+                    print_log(
+                        f"Replaced Image name '{image_str}' with ID {image_family_id}"
+                    )
+                return 1
+        return 0
+
+    # Prepend the namespace when searching for existing templates
+    if namespace is not None:
+        name = f"{namespace}{NAMESPACE_PREFIX_SEPARATOR}{name}"
+
+    source_template_substitutions = 0
+    source_image_id_substitutions = 0
+
     # Dynamic templates don't have 'sources'; return '[]'
-    counter = 0
     for source in resource.get("sources", []):
         template_name_or_id = source["sourceTemplateId"]
         if "ydid:cst:" not in template_name_or_id:
@@ -241,29 +276,24 @@ def create_compute_requirement_template(resource: Dict):
                 )
                 return
             source["sourceTemplateId"] = template_id
-            counter += 1
+            source_template_substitutions += 1
 
-    if counter > 0:
-        print_log(f"Replaced {counter} Compute Source Template name(s) with ID(s)")
+        source_image_id = source.get("imageId")
+        if source_image_id is not None:
+            source_image_id_substitutions += _get_images_id(
+                source_image_id, source, "imageId"
+            )
 
-    # Allow image families to be referenced by name rather than ID
-    global CLEAR_IMAGE_FAMILY_CACHE
-    if CLEAR_IMAGE_FAMILY_CACHE:  # Update the IF cache if required
-        clear_compute_source_template_cache()
-        CLEAR_IMAGE_FAMILY_CACHE = False
+    if source_template_substitutions > 0:
+        print_log(
+            f"Replaced {source_template_substitutions} Compute Source Template name(s) with ID(s)"
+        )
+    if source_image_id_substitutions > 0:
+        print_log(f"Replaced {source_image_id_substitutions} Image name(s) with ID(s)")
 
     images_id = resource.get("imagesId")
     if images_id is not None:
-        if "ydid:imgfam:" not in images_id:
-            image_family_ids = find_image_family_ids_by_name(
-                client=CLIENT, image_family_name=images_id
-            )
-            if len(image_family_ids) > 0:
-                resource["imagesId"] = image_family_ids[0]
-                print_log(
-                    f"Replaced imagesId name '{images_id}' with ID"
-                    f" {image_family_ids[0]}"
-                )
+        _get_images_id(images_id, resource, "imagesId", report=True)
 
     if ARGS_PARSER.dry_run:
         _get_model_object(type, resource)  # Report extras and omissions
@@ -279,9 +309,7 @@ def create_compute_requirement_template(resource: Dict):
         template = CLIENT.compute_client.add_compute_requirement_template(
             compute_template
         )
-        print_log(
-            f"Created Compute Requirement Template '{template.name}' ({template.id})"
-        )
+        print_log(f"Created Compute Requirement Template '{name}' ({template.id})")
         if ARGS_PARSER.quiet:
             print(template.id)
         return
@@ -289,16 +317,14 @@ def create_compute_requirement_template(resource: Dict):
     # Update
     compute_template.id = template_id
     if not confirmed(
-        f"Update existing Compute Requirement Template '{name}'"
-        f" ({template_id})?"
+        f"Update existing Compute Requirement Template '{name}' ({template_id})?"
     ):
         return
     template = CLIENT.compute_client.update_compute_requirement_template(
         compute_template
     )
     print_log(
-        f"Updated existing Compute Requirement Template '{template.name}'"
-        f" ({template.id})"
+        f"Updated existing Compute Requirement Template '{name}'" f" ({template.id})"
     )
     if ARGS_PARSER.quiet:
         print(template.id)
@@ -395,6 +421,8 @@ def create_image_family(resource):
     except KeyError as e:
         raise Exception(f"Expected property to be defined ({e})")
 
+    fq_name = f"{namespace}{NAMESPACE_PREFIX_SEPARATOR}{family_name}"
+
     try:
         os_type = ImageOsType[os_type_str]  # Change to Enum
     except KeyError:
@@ -413,13 +441,15 @@ def create_image_family(resource):
                 namespace=namespace, family_name=family_name
             )
         )  # Raises HTTP 404 Error if not found
-        if not confirmed(f"Update existing Machine Image Family '{family_name}'?"):
+        if not confirmed(f"Update existing Machine Image Family '{fq_name}'?"):
             return
         image_family.id = existing_image_family.id
         # This will update the Image Family but not its constituent
         # Image Group/Image resources
         CLIENT.images_client.update_image_family(image_family)
-        print_log(f"Updated existing Machine Image Family '{family_name}'")
+        print_log(
+            f"Updated existing Machine Image Family '{fq_name}' ('{image_family.id}')"
+        )
         if ARGS_PARSER.quiet:
             print(image_family.id)
     except HTTPError as e:
@@ -427,11 +457,11 @@ def create_image_family(resource):
             # This will create the Image Family and all of its constituent
             # Image Group/Image resources
             image_family = CLIENT.images_client.add_image_family(image_family)
-            print_log(f"Created Machine Image Family '{family_name}'")
+            print_log(f"Created Machine Image Family '{fq_name}' ('{image_family.id}')")
             if ARGS_PARSER.quiet:
                 print(image_family.id)
         else:
-            print_error(f"Failed to create/update Image Family '{image_family}': {e}")
+            print_error(f"Failed to create/update Image Family '{fq_name}': {e}")
         return
 
     # This is an update, so Image Groups have been ignored
@@ -576,26 +606,12 @@ def create_configured_worker_pool(resource: Dict):
     """
     try:
         name = resource["name"]
+        namespace = resource.get("namespace")
     except KeyError as e:
         raise Exception(f"Expected property to be defined ({e})")
 
-    # Multiple Worker Pools with the same name can be created.
-    # Check for existing pool with the same name in an active state.
-    worker_pools: List[WorkerPoolSummary] = (
-        CLIENT.worker_pool_client.find_all_worker_pools()
-    )
-    for worker_pool in worker_pools:
-        if (
-            worker_pool.name == name
-            and worker_pool.type.split(".")[-1] == "ConfiguredWorkerPool"
-            and worker_pool.status
-            not in [WorkerPoolStatus.SHUTDOWN, WorkerPoolStatus.TERMINATED]
-        ):
-            print_log(
-                f"Existing Configured Worker Pool '{name}' ({worker_pool.status}) found"
-                " ... creation cancelled"
-            )
-            return
+    if namespace is not None:
+        name = f"{namespace}{NAMESPACE_PREFIX_SEPARATOR}{name}"
 
     try:
         cwp_request = _get_model_object("AddConfiguredWorkerPoolRequest", resource)
@@ -614,6 +630,7 @@ def create_configured_worker_pool(resource: Dict):
         )
         if ARGS_PARSER.quiet:
             print(cwp_response.workerPool.id)
+
     except Exception as e:
         print_error(f"Unable to created Configured Worker Pool '{name}': {e}")
 
