@@ -2,7 +2,7 @@
 String and numeric constants, etc.
 """
 
-DEFAULT_URL = "https://portal.yellowdog.co/api"
+DEFAULT_URL = "https://api.yellowdog.ai"
 
 YD_KEY = "YD_KEY"
 YD_SECRET = "YD_SECRET"
@@ -20,7 +20,9 @@ CR_BATCH_SIZE_DEFAULT = 10000
 
 TASK_ABORT_CHECK_INTERVAL = 20  # Seconds
 
-NAMESPACE_PREFIX_SEPARATOR = "::"
+NAMESPACE_OBJECT_STORE_PREFIX_SEPARATOR = "::"
+NAMESPACE_PREFIX_SEPARATOR = "/"
+DEFAULT_NAMESPACE = "default"
 WP_VARIABLES_PREFIX = "__"
 WP_VARIABLES_POSTFIX = "__"
 CSV_VAR_OPENING_DELIMITER = "{{"
