@@ -4,11 +4,12 @@
 Command to show the JSON details of YellowDog entities via their IDs.
 """
 
-from typing import List
+from typing import Optional
 
-from yellowdog_client.model import ConfiguredWorkerPool, Task, TaskSearch
-from yellowdog_client.model.exceptions import InvalidRequestException
+from yellowdog_client.model import ConfiguredWorkerPool, Task
 
+from yd_commands.list import get_keyring
+from yd_commands.object_utilities import get_task_by_id
 from yd_commands.printing import print_log, print_warning, print_yd_object
 from yd_commands.wrapper import ARGS_PARSER, CLIENT, main_wrapper
 
@@ -106,15 +107,11 @@ def show_details(ydid: str):
             else:
                 print_warning(f"Task Group ID '{ydid}' not found")
                 return
-            task_search = TaskSearch(
-                workRequirementId=work_requirement.id,
-                taskGroupId=task_group.id,
+            task: Optional[Task] = get_task_by_id(
+                CLIENT, work_requirement.id, task_group.id, ydid
             )
-            tasks: List[Task] = CLIENT.work_client.find_tasks(task_search)
-            for task in tasks:
-                if task.id == ydid:
-                    print_yd_object(task)
-                    return
+            if task is not None:
+                print_yd_object(task)
             else:
                 print_warning(f"Task ID '{ydid}' not found")
 
@@ -135,7 +132,8 @@ def show_details(ydid: str):
             keyrings = CLIENT.keyring_client.find_all_keyrings()
             for keyring in keyrings:
                 if keyring.id == ydid:
-                    print_yd_object(keyring)
+                    # This fetches additional Keyring data: credentials and accessors
+                    print_yd_object(get_keyring(keyring.name))
                     return
             else:
                 print_warning(f"Keyring ID '{ydid}' not found")
